==> cms-db_v0.9.tar.gz: admin/updateinfo.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('updateinfo');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
		<script type="text/javascript" src="jquery.js"></script>
		<script type="text/javascript" src="popuplink.js"></script>
	</head>
	<body>

		<h1><?php locale('title') ?></h1>

		<?php
		if (!function_exists('curl_init')) {
			echo '<p class="error">';
			locale('desc_not-automatic');
			echo '</p>';
			die('</body></html>');
		}
		?>

		<?php
		include('../data/settings/update.inc.php');
		if (isset($_POST['checknow']) || isset($_GET['checknow'])) {

			$update_method = (extension_loaded('ftp') && extension_loaded('zlib')) ? 'auto' : 'manual'; // && (@include 'Archive/Tar.php') == true
			$update_policy = 'unstable'; // will be changed when a stable version exists

			include('updateapi.inc.php');

			$update_version = update_available($update_policy);

			if ($update_version !== false) {

				$update_download = query_update_server('download/'.$update_version);
				$update_info = query_update_server('info/'.$_SESSION['CMS-Locale']);

				?>

				<p class="securitymedium">
					<?php printf(locale('desc_update-available', true), $update_version) ?>
				</p>
				<p class="warning">
					<?php locale('desc_update-backup') ?>
				</p>
				<p class="biglink">
					<a href="<?php echo $update_info ?>" class="popuplink nonewtab">
						<span class="title"><?php locale('link_moreinfo') ?></span>
						<span class="desc"><?php locale('desc_moreinfo') ?></span>
					</a>
				</p>
				<?php if ($update_method == 'auto') { ?>
					<p class="biglink">
						<a href="./update/download.php?<?php echo SID; csrf_protection_get_html() ?>" target="_top" class="nonewtab">
							<span class="title"><?php locale('link_install') ?></span>
							<span class="desc"><?php locale('desc_install') ?></span>
						</a>
					</p>
				<?php } ?>
				<p class="biglink">
					<a href="<?php echo $update_download ?>" class="nonewtab">
						<span class="title"><?php locale('link_download') ?></span>
						<span class="desc"><?php locale('desc_download') ?></span>
					</a>
				</p>

			<?php } else { ?>

				<p class="securityhigh">
					<?php locale('desc_uptodate') ?>
				</p>

			<?php } ?>

		<?php } else { ?>

			<p class="box">
				<?php locale('desc_checkupdate') ?>
			</p>
			<p class="hint">
				<?php locale('desc_updatecheck') ?>
			</p>
			<form action="updateinfo.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
				<input type="submit" name="checknow" value="<?php locale_escape('button_checkupdate', '"') ?>" />
			</form>

		<?php } ?>

	</body>
</html>

==> cms-db_v0.9.3.tar.gz: admin/updateinfo.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');
checkuser('root');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('updateinfo');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
		<script type="text/javascript" src="jquery.js"></script>
		<script type="text/javascript" src="popuplink.js"></script>
	</head>
	<body>

		<h1><?php locale('title') ?></h1>

		<?php
		if (!function_exists('curl_init')) {
			echo '<p class="error">';
			locale('desc_not-automatic');
			echo '</p>';
			die('</body></html>');
		}
		?>

		<?php
		include('../data/settings/update.inc.php');
		if (isset($_POST['checknow']) || isset($_GET['checknow'])) {

			$update_method = (extension_loaded('ftp') && extension_loaded('zlib')) ? 'auto' : 'manual'; // && (@include 'Archive/Tar.php') == true
			$update_policy = 'unstable'; // will be changed when a stable version exists

			include('updateapi.inc.php');

			$update_version = update_available($update_policy);

			if ($update_version !== false) {

				$update_download = query_update_server('download/'.$update_version);
				$update_info = query_update_server('info/'.$_SESSION['CMS-Locale']);

				?>

				<p class="securitymedium">
					<?php printf(locale('desc_update-available', true), $update_version) ?>
				</p>
				<p class="warning">
					<?php locale('desc_update-backup') ?>
				</p>
				<p class="biglink">
					<a href="<?php echo $update_info ?>" class="popuplink nonewtab">
						<span class="title"><?php locale('link_moreinfo') ?></span>
						<span class="desc"><?php locale('desc_moreinfo') ?></span>
					</a>
				</p>
				<?php if ($update_method == 'auto') { ?>
					<p class="biglink">
						<a href="./update/download.php?<?php echo SID; csrf_protection_get_html() ?>" target="_top" class="nonewtab">
							<span class="title"><?php locale('link_install') ?></span>
							<span class="desc"><?php locale('desc_install') ?></span>
						</a>
					</p>
				<?php } ?>
				<p class="biglink">
					<a href="<?php echo $update_download ?>" class="nonewtab">
						<span class="title"><?php locale('link_download') ?></span>
						<span class="desc"><?php locale('desc_download') ?></span>
					</a>
				</p>

			<?php } else { ?>

				<p class="securityhigh">
					<?php locale('desc_uptodate') ?>
				</p>

			<?php } ?>

		<?php } else { ?>

			<p class="box">
				<?php locale('desc_checkupdate') ?>
			</p>
			<p class="hint">
				<?php locale('desc_updatecheck') ?>
			</p>
			<form action="updateinfo.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
				<input type="submit" name="checknow" value="<?php locale_escape('button_checkupdate', '"') ?>" />
			</form>

		<?php } ?>

	</body>
</html>
